@@ -1,5 +1,4 @@
-`psbar` <-
-function(x, cmd="-J -R -W1p -G180 -O -K", file=getOption("gmt.file"), ref=0, digits=getOption("digits"))
+psbar <- function(x, cmd="-J -R -W1p -G180 -O -K", file=getOption("gmt.file"), ref=0, digits=getOption("digits"))
 {
   write.each.bar <- function(bar.row, tmp)
   {
@@ -48,4 +47,3 @@ function(x, cmd="-J -R -W1p -G180 -O -K", file=getOption("gmt.file"), ref=0, dig
 
   invisible(NULL)
 }
-
