@@ -1,5 +1,4 @@
-`pstext` <-
-function(x, cmd="-J -R -O -K", file=getOption("gmt.file"))
+pstext <- function(x, cmd="-J -R -O -K", file=getOption("gmt.file"))
 {
   if(is.null(file)) stop("Please pass a valid 'file' argument, or run gmt(file=\"myfile\").")
   owd <- setwd(dirname(file)); on.exit(setwd(owd))
@@ -10,4 +9,3 @@ function(x, cmd="-J -R -O -K", file=getOption("gmt.file"))
 
   invisible(NULL)
 }
-
